@@ -1,9 +1,12 @@
-#!/bin/bash
+#! /bin/bash
 
 TEXTDOMAINDIR=/usr/share/locale 
 TEXTDOMAIN=antixscreenshot
-# #                           # # ICON TRIAL # #
+
 WORKING_DIR=/home/$USER/scr
+
+SCREENSHOT=Screenshot_$(date +"%Y-%m-%d_%H-%M-%S")
+
 while [ -e "$WORKING_DIR" ] 
 	do
 		WORKING_DIR="/home/$USER/scr$RANDOM"
@@ -13,7 +16,7 @@ cd /home/$USER
 
 
 function preview_full {
-  feh -g 640x480 "$WORKING_DIR"/"$NAME"."$EXT" & yad --image="dialog-question" --window-icon="gnome-screenshot" --title=$"antiXscreenshot" --text=$"Keep this screenshot?" --button="CANCEL:1" --button="OK:0"
+  feh -g 640x480 "$WORKING_DIR"/"$NAME"."$EXT" & yad --image="question" --title=$"antiXscreenshot" --text=$"Keep this screenshot?" --button="CANCEL:1" --button="OK:0"
 
   case "$?" in
   "0")
@@ -37,7 +40,7 @@ function preview_full {
 }
 
 function preview_custom {
-  feh "$WORKING_DIR"/"$NAME"."$EXT" & yad --image="dialog-question" --window-icon="gnome-screenshot" --title=$"antiXscreenshot" --text=$"Keep this screenshot?" --button="CANCEL:1" --button="OK:0";
+  feh "$WORKING_DIR"/"$NAME"."$EXT" & yad --image="question" --title=$"antiXscreenshot" --text=$"Keep this screenshot?" --button="CANCEL:1" --button="OK:0";
 
   case "$?" in
   "0")
@@ -63,7 +66,7 @@ function preview_custom {
 function choose_dir {
   cd /home/$USER
 
-  files=`yad --window-icon="gnome-screenshot" --file-selection --save --filename="$NAME"."$EXT" --title="antiXscreenshot"` 
+  files=`yad --file-selection --save --filename="$NAME"."$EXT" --title="antiXscreenshot"` 
   
   if [ "$files" = "" ] ; then 
     rm -rf "$WORKING_DIR"
@@ -74,7 +77,7 @@ function choose_dir {
     file_ext=${base_name##*.}
     
     if [ "$file_ext" != "$EXT" ] ; then
-      yad --image="dialog-error" --window-icon="gnome-screenshot" --title="antiXscreenshot" --text=$"File extension was changed.\nPlease try again."    
+      yad --image="error" --title="antiXscreenshot" --text=$"File extension was changed.\nPlease try again."    
       choose_dir
     fi
     
@@ -84,17 +87,15 @@ function choose_dir {
 
 function save_shot {
     if [ -e "$dir_path"/"$file_name"."$file_ext" ] ; then
-		yad --title="antiXscreenshot" --image="info_blue" --window-icon="gnome-screenshot" --text=$"File exists. Overwrite? In case\nyou chose ˮNoˮ a counter will\nbe appended to filename." --button=$"Yes":4 --button=$"No":5
+		yad --title="antiXscreenshot" --image="info" --text=$"File exists. Overwrite? In case\nyou chose ˮNoˮ a counter will\nbe appended to filename." --button=$"Yes":4 --button=$"No":5
 		if [ $? == 5 ]; then
 			file_name_cnt="$file_name"
-			v=21
-#			while [ -e "$dir_path"/"$file_name"_"$v"."$file_ext" ] 
-			while [ -e "$dir_path"/"$file_name_cnt"."$file_ext" ] 
+			v=1
+			while [ -e "$dir_path"/"$file_name"_"$v"."$file_ext" ] 
 			do
 				echo $v
 				v=$(($v+1))
-#				file_name_cnt=$(echo "$file_name"_"$v")	
-				file_name_cnt=$(echo "$file_name""$v")		
+				file_name_cnt=$(echo "$file_name"_"$v")	
 			done
 			file_name="$file_name_cnt"
 		fi
@@ -106,16 +107,16 @@ function save_shot {
     rm -rf "$WORKING_DIR"
 
 	if [ -e "$dir_path"/"$file_name"."$file_ext" ]; then
-		yad --window-icon="gnome-screenshot" --title="antiXscreenshot" --timeout=5 --image="info_blue" --text=$"Your screenshot has been saved."
+		yad --title="antiXscreenshot" --timeout=5 --image="info" --text=$"Your screenshot has been saved."
     else
-		yad --window-icon="gnome-screenshot" --title="antiXscreenshot" --image="info_blue" --text=$"Error saving your screenshot. \n File was not saved."
+		yad --title="antiXscreenshot" --image="info" --text=$"Error saving your screenshot. \n File was not saved."
     fi
     
 }
 
 export DIALOG=$(cat <<End_of_Text 
 
-<window title="antiXscreenshot" icon-name="gnome-screenshot" window-position="1">
+<window title="antiXscreenshot" window-position="1">
 
 <vbox>
 <hbox>
@@ -132,7 +133,7 @@ export DIALOG=$(cat <<End_of_Text
 
     <frame `gettext $"Name of image"`>
     <entry>
-      <default>screenshot</default>
+      <default>$SCREENSHOT</default>
       <variable>NAME</variable>
     </entry>
     </frame>
@@ -216,19 +217,19 @@ if [ "$EXIT" = "OK" ] ; then
 
   if [ "$REGION" = $"Full Screen" ] ; then
     if [ "$THUMB" = "true" ] ; then
-      scrot -p -t $PERC -d $DELAY "$WORKING_DIR"/"$NAME"."$EXT"
+      scrot -t $PERC -d $DELAY $n "$WORKING_DIR"/"$NAME"."$EXT"
       preview_full
     else
-      scrot -p -d $DELAY "$WORKING_DIR"/"$NAME"."$EXT"
+      scrot -d $DELAY $n "$WORKING_DIR"/"$NAME"."$EXT"
       preview_full
     fi
   fi
   if [ "$REGION" = $"Custom Area" ] || [ "$REGION" = $"Window" ] ; then
     if [ "$THUMB" = "true" ] ;then
-      scrot -s -t $PERC "$WORKING_DIR"/"$NAME"."$EXT"
+      scrot -s -b -t $PERC $n "$WORKING_DIR"/"$NAME"."$EXT"
       preview_custom
     else
-      scrot -s "$WORKING_DIR"/"$NAME"."$EXT"
+      scrot -s -b $n "$WORKING_DIR"/"$NAME"."$EXT"
       preview_custom
     fi
   fi
